<div align="center">
<h1><code>vidyut-py</code></h1>
<p><i>Python bindings for Vidyut</i></p>
</div>

`vidyut-py` defines Python bindings for [Vidyut][vidyut], a high-performance
Sanskrit toolkit. These bindings are under active development as part of the
[Ambuda][ambuda] project.

[ambuda]: https://ambuda.org
[vidyut]: https://github.com/ambuda-org/vidyut


Installing
----------

Install and update with [pip](https://pip.pypa.io/en/stable/getting-started/):

    $ pip install -U vidyut

Vidyut is more interesting when used with our rich linguistic data, which you
can download here:

    $ wget https://github.com/ambuda-org/vidyut-py/releases/download/0.3.0/data-0.3.0.zip
    $ unzip data-0.3.0.zip

For details on how to use this data, see the [documentation][docs].

[docs]: https://vidyut.readthedocs.io


Links
-----

For users:

- Documentation: https://vidyut.readthedocs.io
- Releases: https://pypi.org/project/vidyut/
- Changes: https://vidyut.readthedocs.io/en/latest/changes.html
- Source Code: https://github.com/ambuda-org/vidyut
- Issues: https://github.com/ambuda-org/vidyut/issues
- Chat: https://discord.gg/7rGdTyWY7Z

For contributors:

- [CONTRIBUTING.md](CONTRIBUTING.md)
